package cn.sagacloud.android.cadengine.items

import android.graphics.*
import android.text.TextPaint
import cn.sagacloud.android.cadengine.Opt
import cn.sagacloud.android.cadengine.types.Space
import cn.sagacloud.android.cadengine.types.TunableSpace
import com.sybotan.android.graphy.SGraphyItem


/**
 * 可调节item
 *
 */
class TunableSpaceItem(val data: TunableSpace, parent: SGraphyItem? = null) : SGraphyItem(parent) {
    /** 画笔 */
    val paint = Paint()
    val centerPaint = Paint()
    val outPaint = Paint()
    private val paintText = TextPaint()

    /** 墙轮廓 */
    private var spacePath: Path? = null
    /** 空间轮廓线坐标list  */
    //private val pointArr = ArrayList<ArrayList<PointF>>()
    /** X坐标最小值  */
    private var minX = 0f

    /** X坐标最大值  */
    private var maxX = 0f

    /** Y坐标最小值  */
    private var minY = 0f

    /** Y坐标最大值  */
    private var maxY = 0f

    var mPoints = ArrayList<PointF>()

    init {
        try {
            zOrder = 1f
            if (data.outLine != null && data.outLine!!.size > 0 && data.outLine!![0].size > 0) {
                minX = 9999999f
                maxX = -9999999f
                minY = 9999999f
                maxY = -9999999f

                for (line in data.outLine!!) {
                    if (line.size < 1) {
                        mPoints.add(PointF(data.outLine!![0][0].x, data.outLine!![0][0].y))
                        continue
                    }
                    var path = Path()
                    path.moveTo(line[0].x, -line[0].y)
                    for (p in line) {
                        if (p.x < minX) {
                            minX = p.x
                        }
                        if (p.x > maxX) {
                            maxX = p.x
                        }
                        if (-p.y < minY) {
                            minY = -p.y
                        }
                        if (-p.y > maxY) {
                            maxY = -p.y
                        }
                        mPoints.add(PointF(p.x, p.y))
                        path.lineTo(p.x, -p.y)
                    }
                    path.close()
                    if (spacePath == null) {
                        spacePath = path
                    } else {
                        // spacePath.b
                    }
                }
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }

        paintText.style = Paint.Style.FILL
        paintText.flags = Paint.ANTI_ALIAS_FLAG
        paintText.color = Opt.textColor
        paintText.textSize = 800f

        paint.style = Paint.Style.FILL
        paint.flags = Paint.ANTI_ALIAS_FLAG
        paint.isAntiAlias = true
        paint.color = Color.parseColor("#007CDB")
        //paint.color = Opt.spaceColor

        outPaint.style = Paint.Style.STROKE
        outPaint.color = Color.parseColor("#7E96FF")
        outPaint.setAntiAlias(true)
        outPaint.strokeWidth = 100f

        centerPaint.style = Paint.Style.STROKE
        centerPaint.color = Color.parseColor("#7E96FF")
        centerPaint.setAntiAlias(true)
        centerPaint.strokeWidth = 200f

    } // Constructor


    /**
     * Item对象边界区域
     *
     * @return SRect
     */
    override fun boundingRect(): RectF {
        return RectF(minX, minY, maxX, maxY)
    } // Function boundingRect()


    /**
     * Item绘制操作
     *
     * @param   canvas          画布
     * @param   rect            绘制区域
     */
    override fun onDraw(canvas: Canvas) {
        if (null != spacePath) {
            if (data.jobStatus.equals("01")) {
                paint.color = Color.parseColor("#EEF496")
            } else {
                paint.color = Color.parseColor("#33F76B65")
            }
            canvas.drawPath(spacePath!!, paint)
        }
        super.onDraw(canvas)
    } // Function onDraw()
} // Class SpaceItem