package com.sybotan.android.demo.viewmodel;

import com.sybotan.android.demo.activities.BaseActivity;
import com.sybotan.android.demo.bean.BaseModel;
import com.sybotan.android.demo.bean.request.ReqAddProblem;
import com.sybotan.android.demo.bean.request.ReqBindQrcode;
import com.sybotan.android.demo.bean.request.ReqCloseProblem;
import com.sybotan.android.demo.bean.request.ReqProblems;
import com.sybotan.android.demo.bean.request.ReqQrcode;
import com.sybotan.android.demo.bean.request.ReqSetJob;
import com.sybotan.android.demo.bean.request.ReqSetProblem;
import com.sybotan.android.demo.bean.request.ReqSpaceJob;
import com.sybotan.android.demo.bean.result.AddProblemModel;
import com.sybotan.android.demo.bean.result.BindQrcodeModel;
import com.sybotan.android.demo.bean.result.CloseProblemModel;
import com.sybotan.android.demo.bean.result.Position;
import com.sybotan.android.demo.bean.result.ProblemsModel;
import com.sybotan.android.demo.bean.result.QrcodeModel;
import com.sybotan.android.demo.bean.result.SetJobModel;
import com.sybotan.android.demo.bean.result.SetProblemModel;
import com.sybotan.android.demo.bean.result.SpaceJobModel;
import com.sybotan.android.demo.bean.result.Z;
import com.sybotan.android.demo.retrofit.BaseObserver;
import com.sybotan.android.demo.retrofit.BaseViewModelInterface;
import com.sybotan.android.demo.retrofit.RetrofitFactory;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

import cn.sagacloud.android.cadengine.items.PointItem;
import cn.sagacloud.android.cadengine.items.TunableSpaceItem;
import cn.sagacloud.android.cadengine.types.Point;
import io.reactivex.Observable;

/**
 * Created by lihao.
 * Date: 2021/6/9
 */
public class GraphyVM extends BaseViewModel {
    //查询空间和任务
    public static final String SPACE_JOB = "SPACE_JOB";
    //添加空间核查问题
    public static final String ADD_PROBLEM = "ADD_PROBLEM";
    //查询空间核查问题
    public static final String GET_PROBLEM = "GET_PROBLEM";
    //设置空间核查问题的信息和状态
    public static final String SET_PROBLEM = "SET_PROBLEM";
    //关闭空间核查问题
    public static final String CLOSE_PROBLEM = "CLOSE_PROBLEM";
    //绑定二维码
    public static final String BIND_QECODE = "BIND_QECODE";
    //查询对象绑定的二维码
    public static final String GET_QECODE = "GET_QECODE";
    //设置空间的任务状态(新建和修改)
    public static final String SET_JOB = "SET_JOB";

    public GraphyVM(BaseViewModelInterface object, BaseActivity activity) {
        super(object, activity);
    }

    /**
     * 查询空间和任务
     */
    public void getSpaceJob() {
        ReqSpaceJob bean = new ReqSpaceJob();
        bean.buildingId = "Bd00022200113a69205aebc34aba87b31a2a03a572ab";
        bean.floorId = "Fl00022200115d43d88abaab46cda43f1596b5e3930b";
        bean.jobStatus.add("01");
        bean.jobStatus.add("02");
        Observable<BaseModel<List<SpaceJobModel>>> observable = RetrofitFactory.getInstance().getSpaceJob(getRequestBody(bean));
        sendRequest(observable, new BaseObserver<List<SpaceJobModel>>(mActivity, this) {
            @Override
            protected void onSuccess(List<SpaceJobModel> spaceJobModels) {
                mEmitter.SendDircetive(SPACE_JOB, spaceJobModels);
            }
        }, true);
    }

    /**
     * 添加空间核查问题
     *
     * @param choseSpace 选中的空间
     * @param x          x坐标
     * @param y          y坐标
     */
    public void addProblem(TunableSpaceItem choseSpace, float x, float y) {
        ReqAddProblem bean = new ReqAddProblem();
        bean.spaceId = choseSpace.getData().getId();
        bean.floorId = "Fl00022200115d43d88abaab46cda43f1596b5e3930b";
        Position position = new Position();
        position.x = x + "";
        position.y = y + "";
        bean.position = position;
        Observable<BaseModel<AddProblemModel>> observable = RetrofitFactory.getInstance().addProblem(getRequestBody(bean));
        sendRequest(observable, new BaseObserver<AddProblemModel>(mActivity, this) {
            @Override
            protected void onSuccess(AddProblemModel model) {
                mEmitter.SendDircetive(ADD_PROBLEM, model);
            }
        }, true);
    }

    /**
     * 查询空间核查问题
     *
     * @param choseSpace 选中的空间
     */
    public void getProblem(@Nullable TunableSpaceItem choseSpace) {
        ReqProblems bean = new ReqProblems();
        bean.floorId = "Fl00022200115d43d88abaab46cda43f1596b5e3930b";
        bean.spaceId = choseSpace.getData().getId();
        Observable<BaseModel<List<ProblemsModel>>> observable = RetrofitFactory.getInstance().problems(getRequestBody(bean));
        sendRequest(observable, new BaseObserver<List<ProblemsModel>>(mActivity, this) {
            @Override
            protected void onSuccess(List<ProblemsModel> models) {
                mEmitter.SendDircetive(GET_PROBLEM, models);
            }
        }, true);
    }

    /**
     * 关闭空间核查问题
     *
     * @param point      点位
     * @param choseSpace 选中的空间
     */
    public void closeProblem(@NotNull PointItem point, @Nullable TunableSpaceItem choseSpace) {
        ReqCloseProblem bean = new ReqCloseProblem();
        bean.problemId = point.getData().getId();
        bean.spaceId = choseSpace.getData().getId();
        Observable<BaseModel<CloseProblemModel>> observable = RetrofitFactory.getInstance().closeProblem(getRequestBody(bean));
        sendRequest(observable, new BaseObserver<CloseProblemModel>(mActivity, this) {
            @Override
            protected void onSuccess(CloseProblemModel setProblemModel) {
                mEmitter.SendDircetive(CLOSE_PROBLEM, null);
            }
        }, true);
    }


    /**
     * 绑定二维码
     *
     * @param choseSpace 选中的空间
     * @param result     二维码uuid
     * @param point      点位信息
     * @param toString   z轴描述
     */
    public void bindQrcode(@Nullable TunableSpaceItem choseSpace, @Nullable String result, @NotNull Point point, @NotNull String toString) {
        ReqBindQrcode bean = new ReqBindQrcode();
        bean.objId = choseSpace.getData().getId();
        bean.objType = "space";
        bean.uuid = result;
        Position position = new Position();
        position.x = String.valueOf(point.getMX());
        position.y = String.valueOf(point.getMY());
        position.z = new Z();
        position.z.offset = toString;
        position.z.region = "wall";
        bean.position = position;
        Observable<BaseModel<BindQrcodeModel>> observable = RetrofitFactory.getInstance().bindQrcode(getRequestBody(bean));
        sendRequest(observable, new BaseObserver<BindQrcodeModel>(mActivity, this) {
            @Override
            protected void onSuccess(BindQrcodeModel bindQrcodeModel) {
                mEmitter.SendDircetive(BIND_QECODE, null);
            }
        }, true);
    }

    /**
     * 查询对象绑定的二维码
     *
     * @param choseSpace 选中的空间
     */
    public void getQrcode(@Nullable TunableSpaceItem choseSpace) {
        ReqQrcode bean = new ReqQrcode();
        bean.objId = choseSpace.getData().getId();
        Observable<BaseModel<ArrayList<QrcodeModel>>> observable = RetrofitFactory.getInstance().qrcode(getRequestBody(bean));
        sendRequest(observable, new BaseObserver<ArrayList<QrcodeModel>>(mActivity, this) {
            @Override
            protected void onSuccess(ArrayList<QrcodeModel> qrcodeModels) {
                mEmitter.SendDircetive(GET_QECODE, qrcodeModels);
            }
        }, true);
    }

    /**
     * 设置空间的任务状态(新建和修改)
     * @param choseSpace 选中的空间
     * @param toString 数字化交付编码
     */
    public void setJob(@Nullable TunableSpaceItem choseSpace, @NotNull String toString) {
        ReqSetJob bean = new ReqSetJob();
        bean.buildingId = "Bd00022200113a69205aebc34aba87b31a2a03a572ab";
        bean.floorId = "Fl00022200115d43d88abaab46cda43f1596b5e3930b";
        bean.spaceId.add(choseSpace.getData().getId());
        bean.jobStatus = "03";
        bean.spaceCode = toString;
        Observable<BaseModel<SetJobModel>> observable = RetrofitFactory.getInstance().setJob(getRequestBody(bean));
        sendRequest(observable, new BaseObserver<SetJobModel>(mActivity, this) {
            @Override
            protected void onSuccess(SetJobModel model) {
                mEmitter.SendDircetive(SET_JOB, null);
            }
        }, true);
    }
}
